; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Single Button |--------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1


;-| Super Motions |--------------------------------------------------------
[Command]
name = "GodEnd"
command = ~D, DB, B, D, DB, B, c+z
time = 35
[Command]
name = "GodEnd"
command = ~D, DB, B, D, DB, B, ~c+z
time = 35

[Command]
name = "ShunGokuSatsu"
command = ~x, x, F, a, ~z
time = 40

[Command]
name = "ReturntoNothingness"
command = ~B, D, DF, F, B, D, DF, F, x
time = 35
[Command]
name = "ReturntoNothingness"
command = ~B, D, DF, F, B, D, DF, F, y
time = 35
[Command]
name = "ReturntoNothingness"
command = ~B, D, DF, F, B, D, DF, F, z
time = 35


[Command]
name = "GiganticPressure1" ; lvl 1
command = ~D, DF, F, D, DB, B, x
time = 35
[Command]
name = "GiganticPressure2" ; lvl 2
command = ~D, DF, F, D, DB, B, y
time = 35
[Command]
name = "GiganticPressure3" ; lvl 3
command = ~D, DF, F, D, DB, B, z
time = 35
[Command]
name = "GiganticPressure1" ; lvl 1
command = ~D, DF, F, D, DB, B, ~x
time = 35
[Command]
name = "GiganticPressure2" ; lvl 2
command = ~D, DF, F, D, DB, B, ~y
time = 35
[Command]
name = "GiganticPressure3" ; lvl 3
command = ~D, DF, F, D, DB, B, ~z
time = 35

[Command]
name = "GenocideHaven1" ; lvl 1
command = ~D, DF, F, D, DF, F, a
time = 30
[Command]
name = "GenocideHaven2" ; lvl 2
command = ~D, DF, F, D, DF, F, b
time = 30
[Command]
name = "GenocideHaven3" ; lvl 3
command = ~D, DF, F, D, DF, F, c
time = 30
[Command]
name = "GenocideHaven1" ; lvl 1
command = ~D, DF, F, D, DF, F, ~a
time = 30
[Command]
name = "GenocideHaven2" ; lvl 2
command = ~D, DF, F, D, DF, F, ~b
time = 30
[Command]
name = "GenocideHaven3" ; lvl 3
command = ~D, DF, F, D, DF, F, ~c
time = 30


;-| Special Motions |------------------------------------------------------
[Command]
name = "Reppuken1" ; slow
command = ~D, DF, F, x
time = 15
[Command]
name = "Reppuken2" ; normal
command = ~D, DF, F, y
time = 15
[Command]
name = "Reppuken3" ; fast
command = ~D, DF, F, z
time = 15
[Command]
name = "Reppuken1" ; slow
command = ~D, DF, F, ~x
time = 15
[Command]
name = "Reppuken2" ; normal
command = ~D, DF, F, ~y
time = 15
[Command]
name = "Reppuken3" ; fast
command = ~D, DF, F, ~z
time = 15

[Command]
name = "GenocideCutter1" ; slow
command = ~F, D, DF, a
[Command]
name = "GenocideCutter2" ; normal
command = ~F, D, DF, b
time = 20
[Command]
name = "GenocideCutter3" ; fast
command = ~F, D, DF, c
time = 20
[Command]
name = "GenocidCutter1" ; slow
command = ~F, D, DF, ~a
time = 20
[Command]
name = "GenocidCutter2" ; normal
command = ~F, D, DF, ~b
time = 20
[Command]
name = "GenocideCutter3" ; fast
command = ~F, D, DF, ~c
time = 20

[Command]
name = "DarkBarrier1" ; slow
command = ~D, DF, F, a
time = 15
[Command]
name = "DarkBarrier2" ; normal
command = ~D, DF, F, b
time = 15
[Command]
name = "DarkBarrier3" ; fast
command = ~D, DF, F, c
time = 15
[Command]
name = "DarkBarrier1" ; slow
command = ~D, DF, F, ~a
time = 15
[Command]
name = "DarkBarrier2" ; normal
command = ~D, DF, F, ~b
time = 15
[Command]
name = "DarkBarrier3" ; fast
command = ~D, DF, F, ~c
time = 15

[Command]
name = "KaiserWave1" ; slow
command = ~B, D, DB, x
[Command]
name = "KaiserWave2" ; normal
command = ~B, D, DB, y
time = 20
[Command]
name = "KaiserWave3" ; fast
command = ~B, D, DB, z
time = 20

[Command]
name = "GodPress1" ; short
command = ~F, D, B, x
[Command]
name = "GodPress2" ; normal
command = ~F, D, B, y
[Command]
name = "GodPress3" ; long
command = ~F, D, B, z
[Command]
name = "GodPress1" ; short
command = ~F, D, B, ~x
[Command]
name = "GodPress2" ; normal
command = ~F, D, B, ~y
[Command]
name = "GodPress3" ; long
command = ~F, D, B, ~z

[Command]
name = "RugalExecution1" ; short
command = ~F, D, B, a
[Command]
name = "RugalExecution2" ; normal
command = ~F, D, B, b
[Command]
name = "RugalExecution3" ; long
command = ~F, D, B, c
[Command]
name = "RugalExecution1" ; short
command = ~F, D, B, ~a
[Command]
name = "RugalExecution2" ; normal
command = ~F, D, B, ~b
[Command]
name = "RugalExecution3" ; long
command = ~F, D, B, ~c

[Command]
name = "GroundDarkSmash1" ; short
command = ~F, D, DF, x
[Command]
name = "GroundDarkSmash2" ; normal
command = ~F, D, DF, y
[Command]
name = "GroundDarkSmash3" ; long
command = ~F, D, DF, z
[Command]
name = "GroundDarkSmash1" ; short
command = ~F, D, DF, ~x
[Command]
name = "GroundDarkSmash2" ; normal
command = ~F, D, DF, ~y
[Command]
name = "GroundDarkSmash3" ; long
command = ~F, D, DF, ~z

[Command]
name = "AirDarkSmash1" ; fast/weak
command = ~D, DF, F, x
[Command]
name = "AirDarkSmash2" ; normal/normal
command = ~D, DF, F, y
[Command]
name = "AirDarkSmash3" ; slow/strong
command = ~D, DF, F, z
[Command]
name = "AirDarkSmash1" ; fast/weak
command = ~D, DF, F, ~x
[Command]
name = "AirDarkSmash2" ; normal/normal
command = ~D, DF, F, ~y
[Command]
name = "AirDarkSmash3" ; slow/strong
command = ~D, DF, F, ~z

[Command]
name = "AshuraSenkuu1" ; full screen/forward
command = ~F, D, DF, y+z
[Command]
name = "AshuraSenkuu1" ; full screen/forward
command = ~F, D, DF, x+z
[Command]
name = "AshuraSenkuu1" ; full screen/forward
command = ~F, D, DF, x+y
[Command]
name = "AshuraSenkuu1" ; full screen/forward
command = ~F, D, DF, ~y+z
[Command]
name = "AshuraSenkuu1" ; full screen/forward
command = ~F, D, DF, ~x+z
[Command]
name = "AshuraSenkuu1" ; full screen/forward
command = ~F, D, DF, ~x+y

[Command]
name = "AshuraSenkuu2" ; full screen/backward
command = ~B, D, DB, y+z
[Command]
name = "AshuraSenkuu2" ; full screen/backward
command = ~B, D, DB, x+z
[Command]
name = "AshuraSenkuu2" ; full screen/backward
command = ~B, D, DB, x+y
[Command]
name = "AshuraSenkuu2" ; full screen/backward
command = ~B, D, DB, ~y+z
[Command]
name = "AshuraSenkuu2" ; full screen/backward
command = ~B, D, DB, ~x+z
[Command]
name = "Ashura Senkuu2" ; full screen/backward
command = ~B, D, DB, ~x+y

[Command]
name = "AshuraSenkuu3" ; half screen/forward
command = ~F, D, DF, b+c
[Command]
name = "AshuraSenkuu3" ; half screen/forward
command = ~F, D, DF, a+c
[Command]
name = "AshuraSenkuu3" ; half screen/forward
command = ~F, D, DF, a+b
[Command]
name = "AshuraSenkuu3" ; half screen/forward
command = ~F, D, DF, ~b+c
[Command]
name = "AshuraSenkuu3" ; half screen/forward
command = ~F, D, DF, ~a+c
[Command]
name = "AshuraSenkuu3" ; half screen/forward
command = ~F, D, DF, ~a+b

[Command]
name = "AshuraSenkuu4" ; half screen/backward
command = ~B, D, DB, b+c
[Command]
name = "AshuraSenkuu4" ; half screen/backward
command = ~B, D, DB, a+c
[Command]
name = "AshuraSenkuu4" ; half screen/backward
command = ~B, D, DB, a+b
[Command]
name = "AshuraSenkuu4" ; half screen/backward
command = ~B, D, DB, ~b+c
[Command]
name = "AshuraSenkuu4" ; half screen/backward
command = ~B, D, DB, ~a+c
[Command]
name = "AshuraSenkuu4" ; half screen/backward
command = ~B, D, DB, ~a+b

[Command]
name = "VanishingDash1" ; weak
command = ~D, DB, B, D, DF, F, x
[Command]
name = "VanishingDash2" ; normal
command = ~D, DB, B, D, DF, F, y
[Command]
name = "VanishingDash3" ; strong
command = ~D, DB, B, D, DF, F, z
[Command]
name = "VanishingDash1" ; weak
command = ~D, DB, B, D, DF, F, x
[Command]
name = "VanishingDash2" ; normal
command = ~D, DB, B, D, DF, F, y
[Command]
name = "VanishingDash3" ; strong
command = ~D, DB, B, D, DF, F, z



;-| Double Tap/Other |-----------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "Super Jump"     ;Required (do not remove)
command = $D, $U
time = 15

[Command]
name = "Roll Forward"     ;Required (do not remove)
command = B, F, a+x
time = 15

[Command]
name = "Roll Backward"     ;Required (do not remove)
command = F, B, a+x
time = 15

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

[Command]
name = "2punchs"
command = x+y
time = 1
[Command]
name = "2punchs"
command = y+z
time = 1
[Command]
name = "2punchs"
command = x+z
time = 1

[Command]
name = "2kicks"
command = a+b
time = 1
[Command]
name = "2kicks"
command = b+c
time = 1
[Command]
name = "2kicks"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1


;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1



;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;---------------------------------------------------------------------------
[State -1, Shun Goku Satsu]
type = ChangeState
value = 3200
triggerall = command = "ShunGokuSatsu"
triggerall = power >= 3000
triggerall = MoveType != H
trigger1 = Statetype = S && Ctrl
trigger2 = StateNo=200||StateNo=210||StateNo=220||StateNo=230 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320||StateNo=330||StateNo=340 && MoveContact
;---------------------------------------------------------------------------
[State -1, God End]
type = ChangeState
value = 3300
triggerall = command = "GodEnd"
triggerall = statetype != A
triggerall = power >= 3000
trigger1 = ctrl
trigger2 = StateNo=230||StateNo=220||StateNo=330||StateNo=340 && MoveContact
;---------------------------------------------------------------------------
[State -1, Return to Nothingness]
type = ChangeState
value = 3400
triggerall = command = "ReturntoNothingness"
triggerall = statetype != A
triggerall = power >= 2000
triggerall = Life >= 101
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, Gigantic Pressure 1]
type = ChangeState
value = 3100
triggerall = command = "GiganticPressure1"
triggerall = power >= 1000
trigger1 = ctrl && statetype != A
trigger2 = (stateno = [200,399]) || (stateno = [400,599])
trigger2 = stateno != 520 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
[State -1, Gigantic Pressure 2]
type = ChangeState
value = 3100
triggerall = command = "GiganticPressure2"
triggerall = power >= 2000
trigger1 = ctrl && statetype != A
trigger2 = (stateno = [200,399]) || (stateno = [400,599])
trigger2 = stateno != 520 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
[State -1, Gigantic Pressure 3]
type = ChangeState
value = 3100
triggerall = command = "GiganticPressure3"
triggerall = power >= 3000
trigger1 = ctrl && statetype != A
trigger2 = (stateno = [200,399]) || (stateno = [400,599])
trigger2 = stateno != 520 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
[State -1, Genocide Haven 1]
type = ChangeState
value = 3000
triggerall = command="GenocideHaven1"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = StateNo=200||StateNo=210||StateNo=220||StateNo=230 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320||StateNo=330||StateNo=340 && MoveContact
;---------------------------------------------------------------------------
[State -1, Genocide Haven 2]
type = ChangeState
value = 3000
triggerall = command="GenocideHaven2"
triggerall = power >= 2000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = StateNo=200||StateNo=210||StateNo=220||StateNo=230 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320||StateNo=330||StateNo=340 && MoveContact
;---------------------------------------------------------------------------
[State -1, Genocide Haven 3]
type = ChangeState
value = 3000
triggerall = command="GenocideHaven3"
triggerall = power >= 3000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = StateNo=200||StateNo=210||StateNo=220||StateNo=230 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320||StateNo=330||StateNo=340 && MoveContact
;---------------------------------------------------------------------------
;Ashura Senkuu (full screen/forward)
[State -1, Ashura Senkuu]
type = ChangeState
value = 1080
triggerall = command = "AshuraSenkuu1"||command="AshuraSenkuu2"||command="AshuraSenkuu3"||command="AshuraSenkuu4"
triggerall = StateType != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Rugal Rush
[State -1, Vanishing Dash]
type = ChangeState
value = 1090
triggerall = (command="VanishingDash1"||command="VanishingDash2"||command="VanishingDash3")
triggerall = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;God Press
[State -1, God Press]
type = ChangeState
value = 1040
triggerall = command ="GodPress1"||command="GodPress2"||command="GodPress3"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,399]) || (stateno = [400,599])
trigger2 = stateno != 520 ;Except for sweep kick
trigger2 = movecontact
;---------------------------------------------------------------------------
;Rugal Execution
[State -1, Rugal Execution]
type = ChangeState
value = 1050
triggerall = (command="RugalExecution1"||command="RugalExecution2"||command="RugalExecution3")
triggerall = statetype != A
trigger1 = ctrl
;--------------------------------------------------------------------------
[State -1, Kaiser Wave]
type = ChangeState
value = 1030
triggerall = (command="KaiserWave1"||command="KaiserWave2"||command="KaiserWave3") &&  statetype != A
triggerall = NumHelper(1031)=0
trigger1 = ctrl
;---------------------------------------------------------------------------
;Dark Smash
[State -1, Dark Smash]
type = ChangeState
value = 1060
triggerall = command ="GroundDarkSmash1"||command="GroundDarkSmash2"||command="GroundDarkSmash3"
triggerall = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Air Dark Smash
[State -1, Air Dark Smash]
type = ChangeState
value = 1070
triggerall = (command="AirDarkSmash1"||command="AirDarkSmash2"||command="AirDarkSmash3")
triggerall = StateType = A
trigger1 = ctrl
trigger2 = (stateno=[600,699])||(stateno = [700,799])
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Genocide Cutter]
type = ChangeState
value = 1010
triggerall = (command="GenocideCutter1"||command="GenocideCutter2"||command="GenocideCutter3") && statetype != A
trigger1 = ctrl
trigger2 = ((StateNo = [200,399]) || StateNo=520) && MoveContact
;---------------------------------------------------------------------------
[State -1, Dark Barrier]
type = ChangeState
value = 1020
triggerall = (command="DarkBarrier1"||command="DarkBarrier2"||command="DarkBarrier3") && statetype != A
trigger1 = ctrl
trigger2 = ((StateNo = [200,399]) || StateNo=520) && MoveContact
;--------------------------------------------------------------------------
[State -1, Reppuken]
type = ChangeState
value = 1000
triggerall = (command="Reppuken1"||command="Reppuken2"||command="Reppuken3") &&  statetype != A
triggerall = NumHelper(1001)=0
trigger1 = ctrl
trigger2 = (StateNo = [200,399])||Stateno=400||StateNo=500 && MoveContact

;===========================================================================
;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Powerup
[State -1, Powerup]
type = ChangeState
value = 805
triggerall = statetype = S
triggerall = power < 3000
trigger1 = ctrl
trigger1 = command = "holdb" && command = "holdy"

;---------------------------------------------------------------------------
[State -1, Evade]
type = ChangeState
value = 810
triggerall = StateType = S
triggerall = Ctrl
trigger1 = command = "x" && command = "a"
;---------------------------------------------------------------------------
[State -1, Evade Punch]
type = ChangeState
value = 811
triggerall = StateType = S
triggerall = StateNo = 810 && Time >= 14
trigger1 = command = "x" || command = "y" || command = "z"
;---------------------------------------------------------------------------
[State -1, Evade Kick]
type = ChangeState
value = 812
triggerall = StateType = S
triggerall = StateNo = 810 && Time >= 14
trigger1 = command = "a" || command = "b" || command = "c"

;---------------------------------------------------------------------------
[State -1, Roll Forward]
type = ChangeState
value = 815
triggerall = StateType != A
triggerall = Ctrl
trigger1 = command = "Roll Forward"
;trigger1 = command = "x" && command = "a" && command = "fwd"

;---------------------------------------------------------------------------
[State -1, Roll Backward]
type = ChangeState
value = 816
triggerall = StateType != A
triggerall = Ctrl
trigger1 = command = "Roll Backward"
;trigger1 = command = "x" && command = "a" && command = "back"

;---------------------------------------------------------------------------
;Throw1
[State -1, Throw1]
type = ChangeState
value = 750
triggerall = statetype = S
triggerall = command = "holdfwd" || command = "holdback"
triggerall = command = "2punchs"
trigger1 = ctrl

;---------------------------------------------------------------------------
;Throw2
[State -1, Throw2]
type = ChangeState
value = 760
triggerall = statetype = S
triggerall = command = "holdfwd" || command = "holdback"
triggerall = command = "2kicks"
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=200||StateNo=300 && MoveContact

;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=200 && MoveContact
trigger3 = StateNo=300||StateNo=310&& MoveContact

;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z" && p2bodydist X >= 10
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=200||StateNo=210 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320 && MoveContact

;---------------------------------------------------------------------------
; Stand Strong Punch (close)
[State -1, Stand Strong Punch (close)]
type = ChangeState
value = 230
triggerall = command = "z" && p2bodydist X < 10
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = statetype = S && ctrl
trigger2 = StateNo=200||StateNo=210 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320 && MoveContact

;---------------------------------------------------------------------------
; Standing Light Kick
[State -1, Standing Light Kick]
type = ChangeState
value = 300
triggerall = command = "a" && p2bodydist X >= 10
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=300||StateNo=310||StateNo=200 && MoveContact

;---------------------------------------------------------------------------
; Standing Light Kick (close)
[State -1, Standing Light Kick (close)]
type = ChangeState
value = 310
triggerall = command = "a" && p2bodydist X < 10
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=300||StateNo=310||StateNo=200 && MoveContact

;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 320
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=200 && MoveContact
trigger3 = StateNo=300||StateNo=310&& MoveContact

;---------------------------------------------------------------------------
; Standing  Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 330
triggerall = command = "c" && p2bodydist X >= 5
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=200||StateNo=210 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320 && MoveContact

;---------------------------------------------------------------------------
; Standing Strong Kick (close)
[State -1, Standing Strong Kick (close)]
type = ChangeState
value = 340
triggerall = command = "c" && p2bodydist X < 5
triggerall = command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = StateNo=200||StateNo=210 && MoveContact
trigger3 = StateNo=300||StateNo=310||StateNo=320 && MoveContact

;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = StateNo=400 && MoveContact

;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = StateNo=400 && MoveContact

;---------------------------------------------------------------------------
; Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = StateNo=400||StateNo=410 && MoveContact

;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 500
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = StateNo=500 && MoveContact

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 510
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = StateNo=500 && MoveContact

;---------------------------------------------------------------------------
; Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 520
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = StateNo=200&&MoveContact
trigger3 = StateNo=300||StateNo=310&&MoveContact
trigger4 = StateNo=400||StateNo=500&& MoveContact

;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 700
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 710
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 720
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
